[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Re: Blends pages, tasks pages etc.



Andreas Tille <andreas@an3as.eu> writes:
> UDD is developed here:
>    ssh://git.debian.org/git/collab-qa/udd.git
> You need to define a new table and write an importer.

As a first attempt, I would like here to add the total number of
installations from popcon (IMO this is a missing number in the
tasks.xhtml/packages.xhtml). I localized the place where the
blends_query_packages SQL function is defined; the patch here would be
simply (in udd.git)

--- a/sql/setup.sql
+++ b/sql/setup.sql
@@ -1506,7 +1506,7
          enh.enhanced,
          rva.releases, versions, rva.architectures,
         upstream_version AS unstable_upstream, debian_mangled_uversion AS unstable_parsed_version, status AS unstable_status,
-        pop.vote, pop.recent,
+        pop.vote, pop.recent, pop.insts,
          tags.debtags,
          screenshot_versions, large_image_urls, small_image_urls,
          bibyear.value    AS "year",

This has to be accompanied in website.git with

--- a/webtools/blendstasktools.py
+++ b/webtools/blendstasktools.py
@@ -317,7 +317,7 @@ query = """PREPARE query_pkgs (text[],text[]) AS
           enhanced text[],
           releases text[], versions text[], architectures text[],
          unstable_upstream text, unstable_parsed_version text, unstable_status text,
           vote int, recent int, -- popcon
           debtags text[],
           screenshot_versions text[], image text[], icon text[],
           year    text,
@@ -1641,6 +1641,7 @@ class TaskDependencies:
 
                 dep.popcon['vote']   = row['vote']
                 dep.popcon['recent'] = row['recent']
+                dep.popcon['insts'] = row['insts']
 
                 # Debtags as sorted list of dict fields
                 if row['debtags']:
@@ -317,7 +317,7 @@ query = """PREPARE query_pkgs (text[],text[]) AS
           releases text[], versions text[], architectures text[],
          unstable_upstream text, unstable_parsed_version text, unstable_status text,
-          vote int, recent int, -- popcon
+          vote int, recent int, insts int, -- popcon
           debtags text[],
           screenshot_versions text[], image text[], icon text[],

Similarly ofcourse with the Python3 version.

Question here: How to synchronize this? The number of arguments on both
sides should match.

Best regards

Ole


Reply to: